==> xmobar-0.50-125-loong64.pkg.tar.zst: usr/share/haskell/register/xmobar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmobar
version:              0.50
visibility:           public
id:                   xmobar-0.50-6sRAD3UqfF7FXBYE2DjzI6
key:                  xmobar-0.50-6sRAD3UqfF7FXBYE2DjzI6
license:              BSD-3-Clause
maintainer:           Jose A. Ortega Ruiz <jao@gnu.org>
author:               Andrea Rossato and Jose A. Ortega Ruiz
homepage:             https://codeberg.org/xmobar/xmobar
synopsis:             A Minimalistic Text Based Status Bar
description:
    Xmobar is a minimalistic text based status bar.

    Inspired by the Ion3 status bar, it supports similar
    features, like dynamic color management, output templates,
    and extensibility through plugins.

category:             System
abi:                  1c3572672966514e1fec31c10d942742
exposed:              True
exposed-modules:
    Xmobar Xmobar.Plugins.Accordion Xmobar.Plugins.Monitors.Common
    Xmobar.Plugins.Monitors.Common.Run
    Xmobar.Plugins.Monitors.Common.Types Xmobar.Plugins.Monitors.Cpu

hidden-modules:
    Paths_xmobar Xmobar.Config.Types Xmobar.Config.Parse
    Xmobar.Config.Template Xmobar.Run.Types Xmobar.Run.Timer
    Xmobar.Run.Template Xmobar.Run.Exec Xmobar.Run.Runnable
    Xmobar.Run.Actions Xmobar.Run.Loop Xmobar.Draw.Boxes
    Xmobar.Draw.Cairo Xmobar.Draw.Types Xmobar.App.Config
    Xmobar.App.Main Xmobar.App.Opts Xmobar.App.Compile
    Xmobar.System.Utils Xmobar.System.StatFS Xmobar.System.Environment
    Xmobar.System.Localize Xmobar.System.Signal Xmobar.System.Kbd
    Xmobar.Text.Ansi Xmobar.Text.Loop Xmobar.Text.Pango
    Xmobar.Text.Swaybar Xmobar.Text.SwaybarClicks Xmobar.Text.Output
    Xmobar.X11.Bitmap Xmobar.X11.CairoSurface Xmobar.X11.ColorCache
    Xmobar.X11.Draw Xmobar.X11.Events Xmobar.X11.Loop Xmobar.X11.Text
    Xmobar.X11.Types Xmobar.X11.Window Xmobar.Plugins.ArchUpdates
    Xmobar.Plugins.Command Xmobar.Plugins.BufferedPipeReader
    Xmobar.Plugins.CommandReader Xmobar.Plugins.Date
    Xmobar.Plugins.EWMH Xmobar.Plugins.HandleReader
    Xmobar.Plugins.QueueReader Xmobar.Plugins.PacmanUpdates
    Xmobar.Plugins.PipeReader Xmobar.Plugins.MarqueePipeReader
    Xmobar.Plugins.StdinReader Xmobar.Plugins.XMonadLog
    Xmobar.Plugins.Kbd Xmobar.Plugins.Locks Xmobar.Plugins.NotmuchMail
    Xmobar.Plugins.Monitors Xmobar.Plugins.Monitors.Batt
    Xmobar.Plugins.Monitors.Batt.Common
    Xmobar.Plugins.Monitors.Common.Output
    Xmobar.Plugins.Monitors.Common.Parsers
    Xmobar.Plugins.Monitors.Common.Files
    Xmobar.Plugins.Monitors.CoreTemp Xmobar.Plugins.Monitors.K10Temp
    Xmobar.Plugins.Monitors.Cpu.Common Xmobar.Plugins.Monitors.CpuFreq
    Xmobar.Plugins.Monitors.Disk Xmobar.Plugins.Monitors.Disk.Common
    Xmobar.Plugins.Monitors.Load Xmobar.Plugins.Monitors.Load.Common
    Xmobar.Plugins.Monitors.Mem Xmobar.Plugins.Monitors.MultiCoreTemp
    Xmobar.Plugins.Monitors.MultiCpu Xmobar.Plugins.Monitors.Net
    Xmobar.Plugins.Monitors.Net.Common Xmobar.Plugins.Monitors.Swap
    Xmobar.Plugins.Monitors.Thermal Xmobar.Plugins.Monitors.ThermalZone
    Xmobar.Plugins.Monitors.Top Xmobar.Plugins.Monitors.Top.Common
    Xmobar.Plugins.Monitors.Uptime Xmobar.Plugins.Monitors.Bright
    Xmobar.Plugins.Monitors.CatInt Xmobar.X11.XRender
    Xmobar.Plugins.Mail Xmobar.Plugins.MBox
    Xmobar.Plugins.Monitors.Wireless Xmobar.Plugins.Monitors.MPD
    Xmobar.Plugins.Monitors.Volume Xmobar.Plugins.Monitors.Alsa
    Xmobar.Plugins.DateZone Xmobar.Plugins.Monitors.Mpris
    Xmobar.System.DBus Xmobar.X11.XPMFile
    Xmobar.Plugins.Monitors.Weather Xmobar.Plugins.Monitors.Batt.Linux
    Xmobar.Plugins.Monitors.Cpu.Linux
    Xmobar.Plugins.Monitors.Disk.Linux
    Xmobar.Plugins.Monitors.Load.Linux
    Xmobar.Plugins.Monitors.Mem.Linux Xmobar.Plugins.Monitors.Net.Linux
    Xmobar.Plugins.Monitors.Swap.Linux
    Xmobar.Plugins.Monitors.Top.Linux
    Xmobar.Plugins.Monitors.Uptime.Linux

import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmobar-0.50
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmobar-0.50
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmobar-0.50
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/loongarch64-linux-ghc-9.6.6/xmobar-0.50
hs-libraries:         HSxmobar-0.50-6sRAD3UqfF7FXBYE2DjzI6
extra-libraries:      Xrandr Xrender Xpm
depends:
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    X11-xft-0.3.4-EvfrEPmujdQFs3QYtwviJ5
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    alsa-core-0.5.0.1-DS67XwizAMDDx6BMv2E7yf
    alsa-mixer-0.3.0.1-D5NqpzQN3mDH3TSCPqK4Sy
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    bytestring-0.11.5.3 cairo-0.13.12.0-BiwVnSgGXm15PnXZRv298w
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    colour-2.3.6-H6QKK8UT9PiEnQ6wB0s1YD containers-0.6.7
    dbus-1.3.3-I7Q67QGi2CK1IKKmdebsoN directory-1.3.8.5
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy filepath-1.4.300.1
    hinotify-0.4.2-KBVoaFnxvyh4b67Iw9rVOg
    http-client-tls-0.3.6.4-2TpGPIcpPZAJDvilQsJ18b
    http-conduit-2.3.9.1-HKTEHoMQbVODlt9daK23ia
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    libmpd-0.10.0.1-7tzHoaoBGtTIYrFuxP4Uq mtl-2.3.1
    netlink-1.1.1.0-KpOHoTN78YV9rxKbrmfxyA
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    pango-0.13.11.0-CJe3nD1y4grDoPVCWTnk4C parsec-3.1.16.1
    parsec-numbers-0.1.0-CQgBTSiqAipDiSzjYC83B3 process-1.6.19.0
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag stm-2.5.1.0
    time-1.12.2 timezone-olson-0.2.1-6NOwi40H6SOHnOnPRUwiEr
    timezone-series-0.1.13-2xWMpmU9QsD6fXDaZdBg8o transformers-0.6.1.0
    unix-2.8.4.0 utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:
    /usr/share/doc/loongarch64-linux-ghc-9.6.6/xmobar-0.50/html/xmobar.haddock

haddock-html:         /usr/share/doc/loongarch64-linux-ghc-9.6.6/xmobar-0.50/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmobar-0.50-127-loong64.pkg.tar.zst: usr/share/haskell/register/xmobar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmobar
version:              0.50
visibility:           public
id:                   xmobar-0.50-JUx378AGAMNBkQfnoD4WDY
key:                  xmobar-0.50-JUx378AGAMNBkQfnoD4WDY
license:              BSD-3-Clause
maintainer:           Jose A. Ortega Ruiz <jao@gnu.org>
author:               Andrea Rossato and Jose A. Ortega Ruiz
homepage:             https://codeberg.org/xmobar/xmobar
synopsis:             A Minimalistic Text Based Status Bar
description:
    Xmobar is a minimalistic text based status bar.

    Inspired by the Ion3 status bar, it supports similar
    features, like dynamic color management, output templates,
    and extensibility through plugins.

category:             System
abi:                  58e3c5da8ff893ad9ab0bd937a6020fd
exposed:              True
exposed-modules:
    Xmobar Xmobar.Plugins.Accordion Xmobar.Plugins.Monitors.Common
    Xmobar.Plugins.Monitors.Common.Run
    Xmobar.Plugins.Monitors.Common.Types Xmobar.Plugins.Monitors.Cpu

hidden-modules:
    Paths_xmobar Xmobar.Config.Types Xmobar.Config.Parse
    Xmobar.Config.Template Xmobar.Run.Types Xmobar.Run.Timer
    Xmobar.Run.Template Xmobar.Run.Exec Xmobar.Run.Runnable
    Xmobar.Run.Actions Xmobar.Run.Loop Xmobar.Draw.Boxes
    Xmobar.Draw.Cairo Xmobar.Draw.Types Xmobar.App.Config
    Xmobar.App.Main Xmobar.App.Opts Xmobar.App.Compile
    Xmobar.System.Utils Xmobar.System.StatFS Xmobar.System.Environment
    Xmobar.System.Localize Xmobar.System.Signal Xmobar.System.Kbd
    Xmobar.Text.Ansi Xmobar.Text.Loop Xmobar.Text.Pango
    Xmobar.Text.Swaybar Xmobar.Text.SwaybarClicks Xmobar.Text.Output
    Xmobar.X11.Bitmap Xmobar.X11.CairoSurface Xmobar.X11.ColorCache
    Xmobar.X11.Draw Xmobar.X11.Events Xmobar.X11.Loop Xmobar.X11.Text
    Xmobar.X11.Types Xmobar.X11.Window Xmobar.Plugins.ArchUpdates
    Xmobar.Plugins.Command Xmobar.Plugins.BufferedPipeReader
    Xmobar.Plugins.CommandReader Xmobar.Plugins.Date
    Xmobar.Plugins.EWMH Xmobar.Plugins.HandleReader
    Xmobar.Plugins.QueueReader Xmobar.Plugins.PacmanUpdates
    Xmobar.Plugins.PipeReader Xmobar.Plugins.MarqueePipeReader
    Xmobar.Plugins.StdinReader Xmobar.Plugins.XMonadLog
    Xmobar.Plugins.Kbd Xmobar.Plugins.Locks Xmobar.Plugins.NotmuchMail
    Xmobar.Plugins.Monitors Xmobar.Plugins.Monitors.Batt
    Xmobar.Plugins.Monitors.Batt.Common
    Xmobar.Plugins.Monitors.Common.Output
    Xmobar.Plugins.Monitors.Common.Parsers
    Xmobar.Plugins.Monitors.Common.Files
    Xmobar.Plugins.Monitors.CoreTemp Xmobar.Plugins.Monitors.K10Temp
    Xmobar.Plugins.Monitors.Cpu.Common Xmobar.Plugins.Monitors.CpuFreq
    Xmobar.Plugins.Monitors.Disk Xmobar.Plugins.Monitors.Disk.Common
    Xmobar.Plugins.Monitors.Load Xmobar.Plugins.Monitors.Load.Common
    Xmobar.Plugins.Monitors.Mem Xmobar.Plugins.Monitors.MultiCoreTemp
    Xmobar.Plugins.Monitors.MultiCpu Xmobar.Plugins.Monitors.Net
    Xmobar.Plugins.Monitors.Net.Common Xmobar.Plugins.Monitors.Swap
    Xmobar.Plugins.Monitors.Thermal Xmobar.Plugins.Monitors.ThermalZone
    Xmobar.Plugins.Monitors.Top Xmobar.Plugins.Monitors.Top.Common
    Xmobar.Plugins.Monitors.Uptime Xmobar.Plugins.Monitors.Bright
    Xmobar.Plugins.Monitors.CatInt Xmobar.X11.XRender
    Xmobar.Plugins.Mail Xmobar.Plugins.MBox
    Xmobar.Plugins.Monitors.Wireless Xmobar.Plugins.Monitors.MPD
    Xmobar.Plugins.Monitors.Volume Xmobar.Plugins.Monitors.Alsa
    Xmobar.Plugins.DateZone Xmobar.Plugins.Monitors.Mpris
    Xmobar.System.DBus Xmobar.X11.XPMFile
    Xmobar.Plugins.Monitors.Weather Xmobar.Plugins.Monitors.Batt.Linux
    Xmobar.Plugins.Monitors.Cpu.Linux
    Xmobar.Plugins.Monitors.Disk.Linux
    Xmobar.Plugins.Monitors.Load.Linux
    Xmobar.Plugins.Monitors.Mem.Linux Xmobar.Plugins.Monitors.Net.Linux
    Xmobar.Plugins.Monitors.Swap.Linux
    Xmobar.Plugins.Monitors.Top.Linux
    Xmobar.Plugins.Monitors.Uptime.Linux

import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmobar-0.50
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmobar-0.50
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmobar-0.50
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/loongarch64-linux-ghc-9.6.6/xmobar-0.50
hs-libraries:         HSxmobar-0.50-JUx378AGAMNBkQfnoD4WDY
extra-libraries:      Xrandr Xrender Xpm
depends:
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    X11-xft-0.3.4-DNl9akEwgHs8a1QW2rAZsW
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    alsa-core-0.5.0.1-DS67XwizAMDDx6BMv2E7yf
    alsa-mixer-0.3.0.1-D5NqpzQN3mDH3TSCPqK4Sy
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    bytestring-0.11.5.3 cairo-0.13.12.0-3aBf3J5x54XF9reOVk3EKF
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z containers-0.6.7
    dbus-1.3.3-INvnWTkkmrECqNpDSboXTA directory-1.3.8.5
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb filepath-1.4.300.1
    hinotify-0.4.2-7jy9U7hnF2eLSCmgfLuzWk
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    libmpd-0.10.0.1-KP9sAQGTWuvKXnknyUi3fo mtl-2.3.1
    netlink-1.1.1.0-KpOHoTN78YV9rxKbrmfxyA
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    pango-0.13.11.0-I7WesFpcii34WA2D3U0oBU parsec-3.1.16.1
    parsec-numbers-0.1.0-CQgBTSiqAipDiSzjYC83B3 process-1.6.19.0
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag stm-2.5.1.0
    time-1.12.2 timezone-olson-0.2.1-6NOwi40H6SOHnOnPRUwiEr
    timezone-series-0.1.13-2xWMpmU9QsD6fXDaZdBg8o transformers-0.6.1.0
    unix-2.8.4.0 utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:
    /usr/share/doc/loongarch64-linux-ghc-9.6.6/xmobar-0.50/html/xmobar.haddock

haddock-html:         /usr/share/doc/loongarch64-linux-ghc-9.6.6/xmobar-0.50/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
